@@ -40,7 +40,8 @@ def _CrypDataBase_ToCursorEncrip(DB_N,DB_Table,Key = "bg8FfNF283UStt0VI5IKQmrYkG
    
     
     Colums_No  = len(L_Column_N)
-    
+    #print "Colums_No " , Colums_No
+    #print 'L_Column_N' , L_Column_N
     L_Column_N = tuple(L_Column_N)
     
     #print L_Column_N
@@ -48,7 +49,7 @@ def _CrypDataBase_ToCursorEncrip(DB_N,DB_Table,Key = "bg8FfNF283UStt0VI5IKQmrYkG
     After_VALUES = ("?,"*Colums_No)[:-1]
     
     SqlInsertPh = "INSERT INTO %s VALUES (%s)" %(DB_Table,After_VALUES)
-    
+    #print 'SqlInsertPh  ' , SqlInsertPh
     PrimaryKeyPh = "%s  PRIMARY KEY , " %(L_Column_N[0] + "   " + L_Column_Type[0])
     
     RestCulumnPh = " "
@@ -60,10 +61,29 @@ def _CrypDataBase_ToCursorEncrip(DB_N,DB_Table,Key = "bg8FfNF283UStt0VI5IKQmrYkG
     restTotallPh = PrimaryKeyPh+RestCulumnPh
 
     CreatTablePh = "CREATE TABLE %s  (%s) " %(DB_Table,restTotallPh)
-
-    L_OldDbconnCursor = list(OldDbconnCursor)
-    Str_OldDbconnCursor = str(L_OldDbconnCursor).strip('[]')
     
+    Coun_Phr = "SELECT COUNT(*) FROM %s;" %(DB_Table)
+    Counted_RowsCur = OldDbconn.execute(Coun_Phr)
+    for Counted_Rows in Counted_RowsCur:
+        #print 'Commit Counted_Rows' , Counted_Rows[0]
+        if Counted_Rows[0] > 1 :
+            L_OldDbconnCursor = list(OldDbconnCursor)
+            Str_OldDbconnCursor = str(L_OldDbconnCursor).strip('[]')
+        if Counted_Rows[0] == 1 :
+            L_OldDbconnCursor = list(OldDbconnCursor)
+            #print 'L_OldDbconnCursor' , L_OldDbconnCursor
+            Str_OldDbconnCursor = str(L_OldDbconnCursor) # without .strip('[]') Here 
+            #print 'Str_OldDbconnCursor',Str_OldDbconnCursor
+        if Counted_Rows[0] == 0 : # Delete the File Here
+            L_OldDbconnCursor = list(OldDbconnCursor)
+            #print 'L_OldDbconnCursor' , L_OldDbconnCursor
+            Str_OldDbconnCursor = str(L_OldDbconnCursor).strip('[]')
+            #print 'Str_OldDbconnCursor',Str_OldDbconnCursor  
+
+    #L_OldDbconnCursor = list(OldDbconnCursor)
+    #Str_OldDbconnCursor = str(L_OldDbconnCursor).strip('[]')
+
+
     L_OldDbconnCursor = [] # تفريغ لتوفير ذاكرة
     
     Ready_To_Encrypt_Phrase = CreatTablePh + '**__SpiltHere__**' + SqlInsertPh+'**__SpiltHere__**'+ Str_OldDbconnCursor
@@ -183,10 +203,17 @@ def _DeCrypDataBase_ToCursorDecrip_IN_Memory(DB_N,NewDB_IN_MmoryConnect,CreatTab
     CreatTablePh_With_Cursor_L = DeCrypPhrase.split('**__SpiltHere__**')
     CreatTablePh =  CreatTablePh_With_Cursor_L[0]
     SqlInsertPh = CreatTablePh_With_Cursor_L[1]
+    #print "SqlInsertPh  ",SqlInsertPh
     Str_Cursor = CreatTablePh_With_Cursor_L[2]
     CreatTablePh_With_Cursor_L = [] #تفريغ لتوفير ذاكرة
+    #print 'Str_Cursor' , Str_Cursor.encode('utf-8')
     CursorListAgain = list(eval(Str_Cursor.encode('utf-8')))
-    
+    #print "CursorListAgain ", CursorListAgain
+    #33333333333333333
+    l2 = []
+    CursorListAgain2 = tuple(CursorListAgain)
+    l2.append(CursorListAgain2)
+    #print 'l2 ' , l2
     if CreatTable == True :
         DeCrypconn.execute(CreatTablePh)
         DeCrypconn.commit()
